@@ -10,9 +10,11 @@ failed=0
 # Build binary
 (( !failed )) && build_knative_client || failed=1
 # Run unit tests
+# Temp disabled due to running into OOM
  (( !failed )) && run_unit_tests || failed=1
 # Serverless operator setup & tests
-(( !failed )) && install_serverless_operator_branch "release-1.13" || failed=1
+# TODO: change branch to "release-1.14" when available
+(( !failed )) && install_serverless_operator_branch "main" || failed=1
 (( !failed )) && run_client_e2e_tests serving || failed=1
 (( !failed )) && run_client_e2e_tests eventing || failed=1
 
