@@ -51,3 +51,13 @@ func TestDescribeChannel(t *testing.T) {
 	assert.Assert(t, util.ContainsAll(out, "messaging.knative.dev", "v1beta1", "InMemoryChannel", "pipe"))
 	cRecorder.Validate()
 }
+
+func TestDescribeChannelURL(t *testing.T) {
+	cClient := v1beta1.NewMockKnChannelsClient(t)
+	cRecorder := cClient.Recorder()
+	cRecorder.GetChannel("pipe", createChannelWithStatus("pipe", "default", &schema.GroupVersionKind{Group: "messaging.knative.dev", Version: "v1beta1", Kind: "InMemoryChannel"}), nil)
+	out, err := executeChannelCommand(cClient, "describe", "pipe", "-o", "url")
+	assert.NilError(t, err, "channel should be described with url as output")
+	assert.Assert(t, util.ContainsAll(out, "pipe-channel.test"))
+	cRecorder.Validate()
+}
